Tech Reference
==============

This part of the documentation is intended to support developers and system
administrators in understanding and extending the internal structure of nidaba.
Its scope is higher level than the internal API documentation but beneath the
command line interface.

.. toctree::
   :maxdepth: 2

   storage
   tasks
